#ifndef NEWPROGRAMWINDOW_H
#define NEWPROGRAMWINDOW_H

#include <QtGui>
#include "xml.h"

class NewProgramWindow : public QMainWindow
{
    Q_OBJECT
public:
    explicit NewProgramWindow(QWidget *parent = 0);
    void load();
signals:

private:
    XML *xml;

    QVBoxLayout *vLayout;
    QListView *lstExercises;
    QStandardItemModel *model;
    QLineEdit *txtName;
    QPushButton *btnSave;

private slots:
    void saveExercise();


};

#endif // NEWPROGRAMWINDOW_H
